<!DOCTYPE TS><TS>
<context>
    <name>String::DayOfWeek</name>
    <message>
        <source>MON</source>
        <translation>LUN</translation>
    </message>
    <message>
        <source>TUE</source>
        <translation>MAR</translation>
    </message>
    <message>
        <source>WED</source>
        <translation>MER</translation>
    </message>
    <message>
        <source>THU</source>
        <translation>JEU</translation>
    </message>
    <message>
        <source>FRI</source>
        <translation>VEN</translation>
    </message>
    <message>
        <source>SAT</source>
        <translation>SAM</translation>
    </message>
    <message>
        <source>SUN</source>
        <translation>DIM</translation>
    </message>
</context>
<context>
    <name>String::WeatherType</name>
    <message>
        <source>Cloudy</source>
        <translation>Couvert</translation>
    </message>
    <message>
        <source>Mostly Cloudy</source>
        <translation>Très nuageux</translation>
    </message>
    <message>
        <source>Partly Cloudy</source>
        <translation>Nuageux</translation>
    </message>
    <message>
        <source>Light Rain</source>
        <translation>Pluie légère</translation>
    </message>
    <message>
        <source>Showers</source>
        <translation>Averses</translation>
    </message>
    <message>
        <source>Rain</source>
        <translation>Pluie</translation>
    </message>
    <message>
        <source>AM Showers</source>
        <translation>Averses matinales</translation>
    </message>
    <message>
        <source>Fog</source>
        <translation>Brouillard</translation>
    </message>
    <message>
        <source>Few Showers</source>
        <translation>Quelques averses</translation>
    </message>
    <message>
        <source>Mostly Sunny</source>
        <translation>Plutôt ensoleillé</translation>
    </message>
    <message>
        <source>Sunny</source>
        <translation>Ensoleillé</translation>
    </message>
    <message>
        <source>Scattered Flurries</source>
        <translation>Fortes rafales</translation>
    </message>
    <message>
        <source>AM Clouds/PM Sun</source>
        <translation>Nuages Matin/Soleil A-Midi</translation>
    </message>
    <message>
        <source>Isolated T-Storms</source>
        <translation>Orages Isolés</translation>
    </message>
    <message>
        <source>Scattered Thunderstorms</source>
        <translation>Orages Violents</translation>
    </message>
    <message>
        <source>PM Showers</source>
        <translation>Averses A-Midi</translation>
    </message>
    <message>
        <source>PM Showers/Wind</source>
        <translation>Averses A-Midi/Vent</translation>
    </message>
    <message>
        <source>Rain/Snow Showers</source>
        <translation>Averses de Pluie/Neige</translation>
    </message>
    <message>
        <source>Few Snow Showers</source>
        <translation>Faibles averses de neige</translation>
    </message>
    <message>
        <source>Cloudy/Wind</source>
        <translation>Nuageux/Vent</translation>
    </message>
    <message>
        <source>Flurries/Wind</source>
        <translation>Bourrasques/Vent</translation>
    </message>
    <message>
        <source>Mostly Cloudy/Windy</source>
        <translation>Plutôt Nuageux/Vent</translation>
    </message>
    <message>
        <source>Rain/Thunder</source>
        <translation>Pluie/Orage</translation>
    </message>
    <message>
        <source>Partly Cloudy/Windy</source>
        <translation>Nuageux/Vent</translation>
    </message>
    <message>
        <source>AM Rain/Snow Showers</source>
        <translation>Pluies/neige Matinales</translation>
    </message>
    <message>
        <source>Light Rain/Wind</source>
        <translation>Pluie Légère/Vent</translation>
    </message>
    <message>
        <source>Showers/Wind</source>
        <translation>Averses/Vent</translation>
    </message>
    <message>
        <source>Mostly Sunny/Wind</source>
        <translation>Plutôt Ensoleillé/Vent</translation>
    </message>
    <message>
        <source>Flurries</source>
        <translation>Bourrasques</translation>
    </message>
    <message>
        <source>Rain/Wind</source>
        <translation>Pluie/Vent</translation>
    </message>
    <message>
        <source>Sct Flurries/Wind</source>
        <translation>fortes rafales/Vent</translation>
    </message>
    <message>
        <source>Sct Strong Storms</source>
        <translation>Orages Violents</translation>
    </message>
    <message>
        <source>PM T-Storms</source>
        <translation>Orages A-Midi</translation>
    </message>
    <message>
        <source>Thunderstorms</source>
        <translation>Orages</translation>
    </message>
    <message>
        <source>Sunny/Windy</source>
        <translation>Ensoleillé/Vent</translation>
    </message>
    <message>
        <source>AM Thunderstorms</source>
        <translation>Orages Matinaux</translation>
    </message>
    <message>
        <source>AM Rain</source>
        <translation>Pluie Matinale</translation>
    </message>
    <message>
        <source>Iso T-Storms/Wind</source>
        <translation>Orages Isolés/Vent</translation>
    </message>
    <message>
        <source>Rain/Snow</source>
        <translation>Pluie/Neige</translation>
    </message>
    <message>
        <source>Sct T-Storms/Wind</source>
        <translation>Orages Violents/Vent</translation>
    </message>
    <message>
        <source>AM Showers/Wind</source>
        <translation>Averses Matinales/Vent</translation>
    </message>
    <message>
        <source>Sct Snow Showers</source>
        <translation>Fortes averses de neige</translation>
    </message>
    <message>
        <source>Snow to Ice/Wind</source>
        <translation>Verglas/Vent</translation>
    </message>
    <message>
        <source>Snow to Rain</source>
        <translation>Neige fondue</translation>
    </message>
    <message>
        <source>AM Light Rain</source>
        <translation>Pluie légère le matin</translation>
    </message>
    <message>
        <source>PM Light Rain</source>
        <translation>Pluie légère l&apos;A-Midi</translation>
    </message>
    <message>
        <source>PM Rain</source>
        <translation>Pluie l&apos;A-Midi</translation>
    </message>
    <message>
        <source>Snow Showers</source>
        <translation>Averses de Neige</translation>
    </message>
    <message>
        <source>Rain to Snow</source>
        <translation>Pluie puis Neige</translation>
    </message>
    <message>
        <source>PM Rain/Snow</source>
        <translation>Pluie/Neige A-Midi</translation>
    </message>
    <message>
        <source>Few Showers/Wind</source>
        <translation>Quelques Averses/Vent</translation>
    </message>
    <message>
        <source>Snow/Wind</source>
        <translation>Neige/Vent</translation>
    </message>
    <message>
        <source>PM Rain/Snow Showers</source>
        <translation>Averses Neige/pluie A-Midi</translation>
    </message>
    <message>
        <source>PM Rain/Snow/Wind</source>
        <translation>Pluie/neige/vent A-Midi</translation>
    </message>
    <message>
        <source>Rain/Snow Showers/Wind</source>
        <translation>Vent Averses Pluie/neige</translation>
    </message>
    <message>
        <source>Rain/Snow/Wind</source>
        <translation>Pluie/Neige/Vent</translation>
    </message>
    <message>
        <source>Light Snow</source>
        <translation>faibles averses neige</translation>
    </message>
    <message>
        <source>PM Snow</source>
        <translation>Neige l&apos;A-Midi</translation>
    </message>
    <message>
        <source>Few Snow Showers/Wind</source>
        <translation>Quelques Averses de Neige/Vent</translation>
    </message>
    <message>
        <source>Light Snow/Wind</source>
        <translation>Quelques flocons/vent</translation>
    </message>
    <message>
        <source>Wintry Mix</source>
        <translation>Temps Hivernal</translation>
    </message>
    <message>
        <source>AM Wintry Mix</source>
        <translation>Temps Hivernal le matin</translation>
    </message>
    <message>
        <source>Hvy Rain/Freezing Rain</source>
        <translation>Forte Pluie/Pluie Verglaçante</translation>
    </message>
    <message>
        <source>AM Light Snow</source>
        <translation>Neige légère le matin</translation>
    </message>
    <message>
        <source>Rain/Freezing Rain</source>
        <translation>Pluie/Pluie verglassante</translation>
    </message>
    <message>
        <source>T-Storms/Wind</source>
        <translation>Orages/Vent</translation>
    </message>
    <message>
        <source>Sprinkles</source>
        <translation>Averses</translation>
    </message>
    <message>
        <source>AM Snow Showers</source>
        <translation>Averses de Neige le matin</translation>
    </message>
    <message>
        <source>AM Clouds/PM Sun/Wind</source>
        <translation>Matin Nuageux/Soleil A-Midi/Vent</translation>
    </message>
    <message>
        <source>AM Rain/Snow/Wind</source>
        <translation>Pluie matinale/Neige/Vent</translation>
    </message>
    <message>
        <source>Rain to Snow/Wind</source>
        <translation>Pluie puis Neige/Vent</translation>
    </message>
    <message>
        <source>Snow to Wintry Mix</source>
        <translation>Neige puis Temps Hivernal</translation>
    </message>
    <message>
        <source>PM Snow Showers/Wind</source>
        <translation>Averses de Neige A-Midi/Vent</translation>
    </message>
    <message>
        <source>Snow and Ice to Rain</source>
        <translation>Neige et Verglas puis Pluie</translation>
    </message>
    <message>
        <source>Heavy Rain</source>
        <translation>Forte Pluie</translation>
    </message>
    <message>
        <source>AM Rain/Ice</source>
        <translation>Pluie matinale/Grêle</translation>
    </message>
    <message>
        <source>AM Snow Showers/Wind</source>
        <translation>Averses de Neige le matin/Vent</translation>
    </message>
    <message>
        <source>AM Light Snow/Wind</source>
        <translation>Neige légère le matin/Vent</translation>
    </message>
    <message>
        <source>PM Light Rain/Wind</source>
        <translation>Pluie légère A-Midi/Vent</translation>
    </message>
    <message>
        <source>AM Light Wintry Mix</source>
        <translation>Léger Temps Hivernal le matin</translation>
    </message>
    <message>
        <source>PM Light Snow/Wind</source>
        <translation>Légère Neige A-Midi/Vent</translation>
    </message>
    <message>
        <source>Heavy Rain/Wind</source>
        <translation>Forte Pluie/Vent</translation>
    </message>
    <message>
        <source>PM Snow Shower</source>
        <translation>Averses de Neige A-Midi</translation>
    </message>
    <message>
        <source>Snow to Rain/Wind</source>
        <translation>Neige puis Pluie/Vent</translation>
    </message>
    <message>
        <source>PM Light Rain/Ice</source>
        <translation>Pluie légère A-Midi/Grêle</translation>
    </message>
    <message>
        <source>AM Snow</source>
        <translation>Neige le matin</translation>
    </message>
    <message>
        <source>Snow to Ice</source>
        <translation>Neige puis grêle</translation>
    </message>
    <message>
        <source>Wintry Mix/Wind</source>
        <translation>Temps Hivernal/Vent</translation>
    </message>
    <message>
        <source>PM Light Snow</source>
        <translation>Neige légère l&apos;A-Midi</translation>
    </message>
    <message>
        <source>AM Drizzle</source>
        <translation>Bruine matinale</translation>
    </message>
    <message>
        <source>Strong Storms/Wind</source>
        <translation>Gros orages/Vent</translation>
    </message>
    <message>
        <source>PM Drizzle</source>
        <translation>Bruine l&apos;A-Midi</translation>
    </message>
    <message>
        <source>Drizzle</source>
        <translation>Bruine</translation>
    </message>
    <message>
        <source>AM Light Rain/Wind</source>
        <translation>Pluie légère le matin/Vent</translation>
    </message>
    <message>
        <source>AM Rain/Wind</source>
        <translation>Pluie matinale/Vent</translation>
    </message>
    <message>
        <source>Wintry Mix to Snow</source>
        <translation>Temps hivernal puis Neige</translation>
    </message>
    <message>
        <source>Snow Showers/Windy</source>
        <translation>Averses de Neige/Vent</translation>
    </message>
    <message>
        <source>Light Rain Shower</source>
        <translation>Légères averses</translation>
    </message>
    <message>
        <source>Light Rain with Thunder</source>
        <translation>Pluie légère et Tonnerre</translation>
    </message>
    <message>
        <source>Light Drizzle</source>
        <translation>Bruine légère</translation>
    </message>
    <message>
        <source>Mist</source>
        <translation>Brume</translation>
    </message>
    <message>
        <source>Smoke</source>
        <translation>Brouillard épais</translation>
    </message>
    <message>
        <source>Haze</source>
        <translation>Ciel Voilé</translation>
    </message>
    <message>
        <source>Light Snow Shower</source>
        <translation>Légères averses de Neige</translation>
    </message>
    <message>
        <source>Light Snow Shower/ Windy</source>
        <translation>Légères averses de Neige/Vent</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Temps Clair</translation>
    </message>
    <message>
        <source>A Few Clouds</source>
        <translation>Quelques Nuages</translation>
    </message>
    <message>
        <source>Fair</source>
        <translation>Beau temps</translation>
    </message>
</context>
<context>
    <name>String::WindDirection</name>
    <message>
        <source>N</source>
        <translation>N</translation>
    </message>
    <message>
        <source>NNE</source>
        <translation>NNE</translation>
    </message>
    <message>
        <source>NE</source>
        <translation>NE</translation>
    </message>
    <message>
        <source>E</source>
        <translation>E</translation>
    </message>
    <message>
        <source>SE</source>
        <translation>SE</translation>
    </message>
    <message>
        <source>SSE</source>
        <translation>SSE</translation>
    </message>
    <message>
        <source>S</source>
        <translation>S</translation>
    </message>
    <message>
        <source>SSW</source>
        <translation>SSO</translation>
    </message>
    <message>
        <source>SW</source>
        <translation>SO</translation>
    </message>
    <message>
        <source>W</source>
        <translation>O</translation>
    </message>
    <message>
        <source>NW</source>
        <translation>NO</translation>
    </message>
    <message>
        <source>NNW</source>
        <translation>NNO</translation>
    </message>
    <message>
        <source>ENE</source>
        <translation>ENE</translation>
    </message>
    <message>
        <source>ESE</source>
        <translation>ESE</translation>
    </message>
    <message>
        <source>WSW</source>
        <translation>OSO</translation>
    </message>
    <message>
        <source>WNW</source>
        <translation>ONO</translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <source>loading...</source>
        <translation>Chargement...</translation>
    </message>
    <message>
        <source>[ retrieving weather data ... ]</source>
        <translation>[ recherche des prévisions météo... ]</translation>
    </message>
    <message>
        <source>current conditions</source>
        <translation>Conditions actuelles</translation>
    </message>
    <message>
        <source>Humidity</source>
        <translation>Humidité</translation>
    </message>
    <message>
        <source>Pressure</source>
        <translation>Pression</translation>
    </message>
    <message>
        <source>Wind</source>
        <translation>Vent</translation>
    </message>
    <message>
        <source>Visibility</source>
        <translation>Visibilité</translation>
    </message>
    <message>
        <source>Wind Chill</source>
        <translation>Sensation</translation>
    </message>
    <message>
        <source>UV Index</source>
        <translation>Indice UV</translation>
    </message>
    <message>
        <source>extended forecast</source>
        <translation>Les 3 prochains jours</translation>
    </message>
    <message>
        <source>LO</source>
        <translation>MIN</translation>
    </message>
    <message>
        <source>HI</source>
        <translation>MAX</translation>
    </message>
    <message>
        <source>today&apos;s forecast</source>
        <translation>Prévisions du jour</translation>
    </message>
    <message>
        <source>tomorrow&apos;s outlook</source>
        <translation>Prévisions pour demain</translation>
    </message>
    <message>
        <source>Forecast for</source>
        <translation>Le temps de</translation>
    </message>
    <message>
        <source>doppler radar</source>
        <translation>Image satellite</translation>
    </message>
    <message>
        <source>Map Unavailable</source>
        <translation>Carte indisponible</translation>
    </message>
    <message>
        <source>RAIN</source>
        <translation>PLUIE</translation>
    </message>
    <message>
        <source>MIX/ICE</source>
        <translation>GRÉSIL</translation>
    </message>
    <message>
        <source>SNOW</source>
        <translation>NEIGE</translation>
    </message>
    <message>
        <source>LIGHT</source>
        <translation>LÉGER</translation>
    </message>
    <message>
        <source>HEAVY</source>
        <translation>FORT</translation>
    </message>
    <message>
        <source>Enter Zip Code</source>
        <translation>Code Postal</translation>
    </message>
    <message>
        <source>weather setup</source>
        <translation>Paramétrage météo</translation>
    </message>
    <message>
        <source>To save, press &apos;i&apos; - to cancel, hit escape</source>
        <translation>Pour enregistrer, appuyez sur &apos;i&apos; - Pour annuler, appuyez sur Escape</translation>
    </message>
    <message>
        <source>COLD</source>
        <translation>FROID</translation>
    </message>
    <message>
        <source>COLDEST</source>
        <translation>TRES FROID</translation>
    </message>
    <message>
        <source>CLOUD TEMPERATURE</source>
        <translation>TEMPERATURE NUAGES</translation>
    </message>
</context>
<context>
    <name>Weather</name>
    <message>
        <source> is invalid)</source>
        <translation> est invalide)</translation>
    </message>
    <message>
        <source>   No Location Set, Please read the README</source>
        <translation>  Lieu non précisé. Merci de lire le fichier README</translation>
    </message>
    <message>
        <source>Configuring MythWeather...</source>
        <translation>Configuration de MythWeather...</translation>
    </message>
    <message>
        <source>Use the right arrow key to select unit conversion...</source>
        <translation>Utilisez la flèche de droite pour choisir l&apos;unité...</translation>
    </message>
    <message>
        <source>Weather Units</source>
        <translation>Unités</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Lieu</translation>
    </message>
    <message>
        <source>Aggressiveness</source>
        <translation>Type de connexion</translation>
    </message>
    <message>
        <source>Configuration Saved...</source>
        <translation>Configuration enregistrée...</translation>
    </message>
    <message>
        <source>Retrieving weather data...</source>
        <translation>Acquisition des données météo...</translation>
    </message>
    <message>
        <source>Use the right arrow key to select your location...</source>
        <translation>Choix du lieu avec la flèche de droite...</translation>
    </message>
    <message>
        <source>Use the right arrow key to select the aggressiveness level...</source>
        <translation>Choix du type de connexion avec la flèche de droite...</translation>
    </message>
    <message>
        <source> 1  High Speed Connection</source>
        <translation>1 Connexion Haut Débit</translation>
    </message>
    <message>
        <source> 8  Medium Speed Connection</source>
        <translation>8 Connexion Débit Moyen</translation>
    </message>
    <message>
        <source> 15 Low Speed Connection</source>
        <translation>15 Connexion Bas Débit</translation>
    </message>
    <message>
        <source>Obtaining initial weather data...</source>
        <translation>Acquisition des données météo...</translation>
    </message>
    <message>
        <source>Updating weather data...</source>
        <translation>Mise à jour des données météo...</translation>
    </message>
    <message>
        <source>Calm</source>
        <translation>Calme </translation>
    </message>
    <message>
        <source> at </source>
        <translation> à </translation>
    </message>
    <message>
        <source>Unlimited</source>
        <translation>illimité</translation>
    </message>
    <message>
        <source> (minimal)</source>
        <translation> (minimal)</translation>
    </message>
    <message>
        <source> (moderate)</source>
        <translation> (modéré)</translation>
    </message>
    <message>
        <source> (high)</source>
        <translation> (élevé)</translation>
    </message>
    <message>
        <source> (extreme)</source>
        <translation> (extrême)</translation>
    </message>
    <message>
        <source>Today a high of </source>
        <translation>Aujourd&apos;hui, les maximales seront de </translation>
    </message>
    <message>
        <source> and a low of </source>
        <translation> °C et la minimale de </translation>
    </message>
    <message>
        <source>. Currently there is a humidity of </source>
        <translation>°C. Le taux d&apos;humidité actuel est de </translation>
    </message>
    <message>
        <source>% and the winds are</source>
        <translation>% et le vent </translation>
    </message>
    <message>
        <source> calm.</source>
        <translation>est calme. </translation>
    </message>
    <message>
        <source> coming in at </source>
        <translation> souffle à </translation>
    </message>
    <message>
        <source> mph from the </source>
        <translation>mph de secteur </translation>
    </message>
    <message>
        <source> Km/h from the </source>
        <translation> km/h de secteur </translation>
    </message>
    <message>
        <source> Visibility will be unlimited for today.</source>
        <translation> La visibilité du jour est illimitée.</translation>
    </message>
    <message>
        <source> Visibility conditions are unknown.</source>
        <translation> Les conditions de visibilité sont inconnues.</translation>
    </message>
    <message>
        <source> There will be a visibility of </source>
        <translation> La visibilité sera de </translation>
    </message>
    <message>
        <source> miles.</source>
        <translation> miles.</translation>
    </message>
    <message>
        <source> km.</source>
        <translation> km.</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Dimanche</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Lundi</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Mardi</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Mercredi</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Jeudi</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Vendredi</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Samedi</translation>
    </message>
    <message>
        <source>Date Error</source>
        <translation>Erreur de date</translation>
    </message>
    <message>
        <source>Tomorrow expect a high of </source>
        <translation>Demain, la maximale sera de </translation>
    </message>
    <message>
        <source>Expected conditions: </source>
        <translation>Prévision : </translation>
    </message>
    <message>
        <source>Weather data from: </source>
        <translation>Bulletin météo du </translation>
    </message>
    <message>
        <source>Updating...</source>
        <translation>Mise à jour...</translation>
    </message>
    <message>
        <source> (Not All Information Available)</source>
        <translation>(Certaines informations sont indisponibles)</translation>
    </message>
    <message>
        <source>*** Invalid Area ID or Server Error ***</source>
        <translation>*** Code Inconnu ou Erreur du Serveur ***</translation>
    </message>
    <message>
        <source>Imperial (Fahrenheit, in, etc)</source>
        <translation>Impérial (Fahrenheit, in, etc)</translation>
    </message>
    <message>
        <source>Metric (Celsius, kPa, etc)</source>
        <translation>Métrique (Celsius, kPA, etc)</translation>
    </message>
    <message>
        <source> F</source>
        <translation> °F</translation>
    </message>
    <message>
        <source> C</source>
        <translation> °C</translation>
    </message>
    <message>
        <source>.</source>
        <translation>.</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Inconnu</translation>
    </message>
    <message>
        <source> - PAUSED -</source>
        <translation>- EN PAUSE -</translation>
    </message>
    <message>
        <source>doppler radar</source>
        <translation type="obsolete">radar doppler</translation>
    </message>
    <message>
        <source>satellite image</source>
        <translation type="obsolete">image satellite</translation>
    </message>
    <message>
        <source>Myth was unable to retrieve your weather data within the time allowed (%1 seconds).
Press OK to try again with a larger timeout value. Press Cancel to try again without animated radar maps.</source>
        <translation>Myth n&apos;est pas capable de retrouver les données météo dans le temps imparti (%1 secondes). 
Presser OK pour essayer encore avec un délai plus grand. 
Presser sur Annuler pour réessayer sans les données radar animées.</translation>
    </message>
    <message>
        <source>Myth was unable to retrieve your weather data within the time allowed (%1 seconds).
Press OK to try again with a larger timeout value. Press Cancel to abort.</source>
        <translation>Myth n&apos;est pas capable de retrouver les données météo dans le temps imparti (%1 secondes). 
Presser OK pour essayer encore avec un délai plus grand. 
Presser sur Annuler pour arrêter.</translation>
    </message>
</context>
</TS>
